@@ -1,11 +1,10 @@
-#!/usr/bin/perl
 package Bundle::SYP;
 # ABSTRACT: SYP's cozy environment
 
 use strict;
 use utf8;
 use warnings 'all';
-our $VERSION = '1.2'; # VERSION
+our $VERSION = '1.3'; # VERSION
 
 1;
 
@@ -21,7 +20,7 @@ Bundle::SYP - SYP's cozy environment
 
 =head1 VERSION
 
-version 1.2
+version 1.3
 
 =head1 SYNOPSIS
 
@@ -32,6 +31,10 @@ version 1.2
 
 =head1 CONTENTS
 
+Module::Install
+
+XML::LibXML
+
 YAML
 
 Term::ANSIColor
@@ -70,6 +73,8 @@ Data::Float
 
 Data::Printer
 
+Data::Printer::Filter::JSON
+
 Data::Printer::Filter::URI
 
 DateTime::Format::ISO8601
@@ -84,6 +89,8 @@ Devel::REPL
 
 Devel::REPL::Plugin::DataPrinter
 
+Devel::Trace
+
 Digest::MD5
 
 Digest::SHA
@@ -122,15 +129,17 @@ File::Slurp
 
 FindBin::libs
 
+Geo::DNA
+
 Geo::Distance
 
 Geo::GoogleEarth::Pluggable
 
 HTML::AsText::Fix
 
-HTML::TreeBuilder::LibXML
+HTML::Linear
 
-HTML::Untemplate
+HTML::TreeBuilder::LibXML
 
 HTTP::Tiny
 
@@ -148,6 +157,8 @@ List::MoreUtils
 
 Log::Log4perl
 
+LWP::Protocol::Net::Curl
+
 LWP::Simple
 
 Memoize
